@@ -3,7 +3,6 @@
 
 name = 'plain_db'
 import os
-import sys
 
 def getFile(fn):
 	result = {}
@@ -32,8 +31,8 @@ class DB(object):
 		oldValue = self.items.get(key, 0)
 		self.update(key, oldValue + value)
 
-	def get(self, key):
-		return self.items.get(key)
+	def get(self, key, default=None):
+		return self.items.get(key) or default
 
 	def save(self):
 		lines = [key + ' ' + str(self.items[key]) for key in self.items]
